package ctbrec.ui.tabs.recorded;

import static ctbrec.ui.Icon.*;

import java.io.IOException;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;
import java.util.Map;
import java.util.Optional;
import java.util.stream.Collectors;

import ctbrec.Model;
import ctbrec.ModelGroup;
import ctbrec.recorder.Recorder;
import ctbrec.ui.controls.Dialogs;
import javafx.scene.image.ImageView;

public class ModelNameTableCell extends IconTableCell<String> {

    private Recorder recorder;

    public ModelNameTableCell(Recorder recorder) {
        super(Map.of(GROUP_16, new ImageView(GROUP_16.url())));
        this.recorder = recorder;
    }

    @Override
    protected void updateItem(String item, boolean empty) {
        setText(null);
        tooltip = null;
        hide(GROUP_16);

        if (item != null && !empty) {
            setText(item);
            Model m = getTableView().getItems().get(getTableRow().getIndex());
            Optional<ModelGroup> optionalGroup = getModelGroup(m);
            if (optionalGroup.isPresent()) {
                ModelGroup group = optionalGroup.get();
                setText(group.getName() + " (aka " + item + ')');
                show(GROUP_16);
                tooltip = group.getModelUrls().size() + " models:\n";
                tooltip += group.getModelUrls().stream().collect(Collectors.joining("\n"));
            }
        }
        super.updateItem(item, empty);
    }

    private Optional<ModelGroup> getModelGroup(Model model) {
        try {
            return recorder.getModelGroup(model);
        } catch (InvalidKeyException | NoSuchAlgorithmException | IOException e) {
            Dialogs.showError(getScene(), "Error", "Couldn't get model group for model " + model, e);
            return Optional.empty();
        }
    }
}
